#
# spec file for package greybird-geeko-theme
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define name_light Greybird-geeko
%define name_dark Greybird-geeko-dark
%define _name Greybird-Geeko

Name:           greybird-geeko-theme
Version:        3.23.4+git0.c1d46c3
Release:        bp156.3.3.1
URL:            https://github.com/shimmerproject/Greybird-Geeko
Summary:        A grey theme for GNOME, XFCE, GTK+ 2 and 3
License:        (CC-BY-SA-3.0 OR GPL-2.0-or-later) AND GPL-3.0-or-later
Group:          System/GUI/GNOME
Source:         %{_name}-%{version}.tar.zst
# PATCH-FIX-OPENSUSE disable-unity_v3.23.1.patch maurizio.galli@gmail.com -- remove unity desktop
Patch0:         disable-unity_v3.23.1.patch
%if 0%{?sle_version} >= 150400 && 0%{?is_opensuse}
# PATCH-FIX-OPENSUSE link-selected-is-optional.patch manfred.h@gmx.net -- work around too old gtk4 libs on Leap 15.4 and 15.5
Patch1:         link-selected-is-optional.patch
%endif
BuildRequires:  fdupes
BuildRequires:  gdk-pixbuf-devel
BuildRequires:  gdk-pixbuf-loader-rsvg
BuildRequires:  glib2-devel
BuildRequires:  meson
BuildRequires:  sassc
BuildRequires:  zstd
BuildRequires:  pkgconfig(gtk4)
BuildArch:      noarch

%description
This theme for GTK2/3 and xfwm4/emerald/metacity is a
fork of Greybird with openSUSE branding elements added.

%package -n metatheme-greybird-geeko-common
Summary:        Common files for the Greybird theme
Group:          System/GUI/GNOME
Suggests:       gtk2-metatheme-greybird-geeko
Suggests:       gtk3-metatheme-greybird-geeko
Suggests:       gtk4-metatheme-greybird-geeko

%description -n metatheme-greybird-geeko-common
The Greybird theme for GTK2/3/4 and xfwm4/emerald/metacity started out on the
basis of Bluebird, but aims at reworking the intense blue tone to a more
neutral grey-ish look.

This package provides the files common to the GTK+ themes and the window
manager themes as well as background images.

%package -n gtk2-metatheme-greybird-geeko
Summary:        GTK+ 2 support for the Greybird theme
Group:          System/GUI/GNOME
Requires:       gtk2-engine-murrine
Requires:       metatheme-greybird-geeko-common = %{version}
Supplements:    packageand(metatheme-greybird-geeko-common:gtk2)

%description -n gtk2-metatheme-greybird-geeko
This package provides the GTK+ 2 support of Greybird-geeko.

%package -n gtk3-metatheme-greybird-geeko
Summary:        GTK+ 3 support for the Greybird-geeko theme
Group:          System/GUI/GNOME
Requires:       metatheme-greybird-geeko-common = %{version}
Supplements:    packageand(metatheme-greybird-geeko-common:gtk3)

%description -n gtk3-metatheme-greybird-geeko
This package provides the GTK+ 3 support of Greybird-geeko.

%package -n gtk4-metatheme-greybird-geeko
Summary:        GTK+ 4 support for the Greybird-geeko theme
Group:          System/GUI/GNOME
Requires:       metatheme-greybird-geeko-common = %{version}
Supplements:    packageand(metatheme-greybird-geeko-common:gtk4)

%description -n gtk4-metatheme-greybird-geeko
This package provides the GTK+ 4 support of Greybird-geeko.

%prep
%setup -q -n %{_name}-%{version}
%autopatch -p1

%build
%meson
%meson_build

%install
%meson_install

# the convulted fdupes call is necessary, else a gtk-2.0 icon will be linked to gtk-3.0
# which will not work if only one subpackage is installed.
%fdupes -s %{buildroot}/%{_datadir}/themes/{%{name_light},%{name_dark}}*/{[^g]*,gtk-3.0}

%fdupes -s %{buildroot}/%{_datadir}/themes/{%{name_light},%{name_dark}}/gtk-2.0/*

%files -n metatheme-greybird-geeko-common
%doc README.md
%license LICENSE.CC LICENSE.GPL
%dir %{_datadir}/themes/{%{name_light},%{name_dark},%{name_light}-bright}
%{_datadir}/themes/{%{name_light},%{name_dark}}/{%{name_light},%{name_dark}}.emerald
%{_datadir}/themes/{%{name_light},%{name_dark}}/metacity-1
%{_datadir}/themes/{%{name_light},%{name_light}-bright}/xfce-notify-4.0
%{_datadir}/themes/{%{name_light},%{name_dark}}/xfwm4
%{_datadir}/themes/{%{name_light},%{name_dark}}/index.theme
%dir %{_datadir}/themes/{%{name_light},%{name_dark}}/gnome-shell
%{_datadir}/themes/{%{name_light},%{name_dark}}/gnome-shell/*
%dir %{_datadir}/themes/{%{name_light},%{name_dark}}/plank
%{_datadir}/themes/{%{name_light},%{name_dark}}/plank/*
%dir %{_datadir}/themes/{%{name_light},%{name_dark}}-{accessibility,compact}
%{_datadir}/themes/{%{name_light},%{name_dark}}-{accessibility,compact}/*

%files -n gtk2-metatheme-greybird-geeko
%{_datadir}/themes/{%{name_light},%{name_dark}}/gtk-2.0

%if 0%{?suse_version} >= 1210
%files -n gtk3-metatheme-greybird-geeko
%{_datadir}/themes/{%{name_light},%{name_dark}}/gtk-3.0
%endif

%files -n gtk4-metatheme-greybird-geeko
%{_datadir}/themes/{%{name_light},%{name_dark}}/gtk-4.0

%changelog
* Thu Dec 19 2024 maurizio.galli@gmail.com
- Update to version 3.23.4+git0.c1d46c3:
  * Sync with Greybird up to commit 7e4507d7713b2aaf41f8cfef2a1a9e214a4d8b6f
  * Fix label styles for xfdesktop 4.19
  * Stop forcing icon style for sidebars
  * Style hover/active undecorated buttons same as normal
  * Handle toolbar CSS class
  * Style item menubar nodes
  * xfwm4: Fix "Hide frame when maximized" ignoring top frame
  * xfwm4: Improve tabwin contrast
  * xfwm4: Bump tabwin preview to 128px
  * xfwm4: Remove dark line below titlebar
  * Decrease Gnome Software's headerbar height
- Patches removed as no longer needed:
  * git7e4507d7713b2aaf41f8cfef2a1a9e214a4d8b6f-fix-label-styles-for-xfdesktop-4.19.patch
* Wed Dec 18 2024 Manfred Hollstein <manfred.h@gmx.net>
- Add new patch
  git7e4507d7713b2aaf41f8cfef2a1a9e214a4d8b6f-fix-label-styles-for-xfdesktop-4.19.patch
- Refresh link-selected-is-optional.patch
* Tue Feb 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Feb 21 2023 Manfred Hollstein <manfred.h@gmx.net>
- Make "*:link:selected" optional to work around too old gtk4 libs
  on Leap 15.5, too.
* Sat Jan 14 2023 Manfred Hollstein <manfred.h@gmx.net>
- Make "*:link:selected" optional to work around too old gtk4 libs
  on Leap 15.4; add link-selected-is-optional.patch
* Tue Jun 28 2022 Maurizio Galli <maurizio.galli@suse.com>
- Prevent Unity desktop theme from being installed
  Added disable-unity_v3.23.1.patch
* Mon Jun 27 2022 maurizio.galli@gmail.com
- Update to version 3.23.1+git1.77c0887:
  * Cleanup leftovers and correct emerald file mistakinly being renamed
* Mon Jun 27 2022 maurizio.galli@gmail.com
- Update to version 3.23.1+git0.a96e825:
  * Sync with Greybird 3.23.1
  * Add initial support for Gtk4 and libhandy
  * Fix dark xfwm4-a11y install path
  * Fix xfwm4-a11y and xfwm4-compact install path
  * Fix: GtkLabel: Backdropped selection color adjusted
  * Fix: Backdropped selection: GtkListBoxes weren't grey
  * Hotfix: removed background color for non-bg items
  * Gtk3: Adjusted selected backdrop fg/bg colors: shades of grey.
  * Changes the xfwm4 border colors
  * build: refactor meson
  * Correct gradients for horizontal scrollbars
  * Reduce messagedialog buttonbox size
  * Make CSD titlebars slimmer
  * Correct gradients for horizontal scrollbars (shimmerproject/Greybird#288)
  * Greybird-Dark titlebar decorations now match their CSD counterparts (shimmerproject/Greybird#301)
  * Background selection colors are now grey instead of blue for better readability
  * Add initial support for Gtk4 and libhandy
  * Install index.theme
* Fri Dec 18 2020 maurizio.galli@gmail.com
- Update to version 3.22.11+git10.2f4304a:
  * Reduce messagedialog buttonbox size
  * Make CSD titlebars slimmer
  * Improve dark xfwm4 tabwin contrast
  * More normal-sized inline-toolbar buttons
  * Add workaround for Gnome Builder
  * Fix progressbar in unfocused windows
* Sat Nov 28 2020 maurizio.galli@gmail.com
- Update to version 3.22.11+git2.751e0f3:
  * Rebase parts of the %%linked code
* Sun Aug  9 2020 Stefan Seyfried <seife+obs@b1-systems.com>
- fix version number
* Mon Aug  3 2020 maurizio.galli@gmail.com
- Update to version v3.22.11+git1.968e3b5:
  * Improve contrast of gtk2 selection background color
* Fri Feb 28 2020 maurizio.galli@gmail.com
- Update to version 3.22.10.1+git52.ef9302a:
  * Use correct theme path for notifyd
* Fri Feb 28 2020 maurizio.galli@gmail.com
- Update to version 3.22.10.1+git50.4465523:
  * Sync with Greybird upstream
* Sat Dec 21 2019 maurizio.galli@gmail.com
- Update to version 3.22.10.1+git48.35f7cb8:
  * Make use of symlinks
  * Add single-user installation instructions
  * Added xfwm4 dark accessibility theme
  * Update to upstream master
* Wed Jul 17 2019 Carson Black <uhhadd@gmail.com>
- Update to version 3.22.10.1+git39.ffde076:
  * Work around Meson bug that prevents Leap from building
* Tue Jul 16 2019 maurizio.galli@gmail.com
- Update to version 3.22.10.1+git38.1a7574f:
  * Merge bright into lights notification theme, and drop darks bright theme
  * Install bright notification files to proper places
  * Add flags for flatpak usage
* Mon Jul  8 2019 maurizio.galli@gmail.com
- Update to version 3.22.10.1+git33.0c9d808:
  * Theme is now split in Light and Dark variants
  * Added xfwm dark theme
  * Improved xfwm inactive buttons contrast
  * Meson port
  * Update README.md to reflect meson
  * Remove unused themes
- Updated and optimized spec file to build with meson
* Fri Jun 21 2019 maurizio.galli@gmail.com
- Update to version 3.22.10.1+git5.316475b:
  * Tweak dark colors
  * Added theme-preview
* Tue Jun 18 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Added license gpl-3.0-or-later for metacity theme
- Fixed _service file to follow naming guidelines ("+" replaced "~")
* Mon Jun 17 2019 maurizio.galli@gmail.com
- Update to version 3.22.10.1~git2.5f0e6a9:
  * Update README.md
* Mon Jun 17 2019 maurizio.galli@gmail.com
- Update to version 3.22.10.1~git0.8782e39:
  * Update README.md
  * Update index.theme
  * Added Makefile.am.
  * Added Greybird-geeko.emerald.
  * Update README.md
  * Update to differentiate between Greybird openSUSE and upstream Greybird
  * openSUSE colour palette
  * Improve button sizing
  * Make error and warning entry text more readable
  * Also set backdrop color for print dialog (Fixes #243)
* Mon Jun 17 2019 Maurizio Galli <maurizio.galli@gmail.com>
- changed URL as it's now part of the Shimmer Project
  - https://shimmerproject.org/
  - https://github.com/shimmerproject/Greybird-Geeko
- added service file for fetching sources
* Fri May 31 2019 Carson Black <uhhadd@gmail.com>
- Initial package greybird-geeko-theme
